/*
 ParticularLights.jsx
 version: 1.1
 author: Charles Bordenave (www.motionboutique.com)
 date: 21 May 2014
*/


function ParticularLights()
{
	// Variable used to keep track of 'this' reference
	var particularLights = this;

	// Create an instance of the utils class to use its functions
	var utils = new ParticularLightsUtils();

	// Script infos
	this.scriptMinSupportVersion = "11.0";
	this.scriptName = "ParticularLights.jsx";
	this.scriptVersion = "1.1";
	this.scriptTitle = "Particular Lights";
	this.scriptCopyright = "Copyright (c) 2014 Motion Boutique";
	this.scriptHomepage = "http://www.motionboutique.com";
	this.scriptDescription = {en:"This script attaches a light to each selected layer. Note that each created light is linked to the layer below it.",
							  fr:"Ce script attache une lumière à chaque calque sélectionné. Notez que chaque lumière créée est liée au calque situé en-dessous de lui."};
	this.scriptAbout = {en:this.scriptName + ", v" + this.scriptVersion + "\\r" + this.scriptCopyright + "\\r" + this.scriptHomepage + "\\r\\r" + utils.loc(this.scriptDescription),
						fr:this.scriptName + ", v" + this.scriptVersion + "\\r" + this.scriptCopyright + "\\r" + this.scriptHomepage + "\\r\\r" + utils.loc(this.scriptDescription)};
	this.scriptUsage = {en:	"\u25BA In After Effects CS6 or later, select at least one layer \\r" +
							"\u25BA Run the script \\r" +
							"\u25BA Click on Create",
						fr:	"\u25BA Dans After Effects CS6 ou supérieur, sélectionnez au moins un calque \\r" +
							"\u25BA Exécutez le script \\r" +
							"\u25BA Cliquez sur Créer"};

	// Errors
    this.requirementErr = {en:"This script requires After Effects CS6 or later.", fr:"Ce script nécessite After Effects CS6 ou supérieur."};
	this.selAVLayerErr = {en:"Select at least one layer.", fr:"Sélectionnez au moins un calque."};

   	// UI strings & defaults
	this.aboutBtnName = "?";
	this.hideAndShyCbName = {en:"Hide and Shy Original Layers", fr:"Masquer les calques d\\'origine"};
	this.runBtnName = {en:"Create", fr:"Créer"};

	// header image
	this.headerImgData = "\u0089PNG\r\n\x1A\n\x00\x00\x00\rIHDR\x00\x00\x00\u00AA\x00\x00\x002\b\x06\x00\x00\x00\u00CCC@\u00AC\x00\x00\x00\tpHYs\x00\x00\x00\x01\x00\x00\x00\x01\x018\"\u00F4@\x00\x00\x00$zTXtCreator\x00\x00x\u009CsL\u00C9OJUpL+I-RpMKKM.)\x06\x00Az\x06\u00CE\u00E7\u00CDsf\x00\x00\x17\u00DAIDATx\u009C\u00DD\u009Dw|\\\u00D5\u0095\u00C7\u00BFOSU\u00AC\u00AEQ/F\u00EE\r\u00DC0\u00B6,\u00F7\x02\x06\x17\u00B0cC\x02\u00C1$!\x01\u00B2\u00D9\u00D4]6\u009FM\u00D8\u0094OHv!\u0085d\u0093,\u0084,\x1B\x02\x0E\x04p\f\x0E6\u00B616\u0092m\u00B9\b\x17\u00B9\u00CB\u0092\u00D5{\u00AF\u00A3\u00914\u00F3\u00F6\u008F\u0091f\u00E6\u00CD\u00BC\u00F7\u00E6\u00CDhl\b?\x18\u00F1\u00E6\u00DEs\u00CF9\u00F7\u00BE\u00DF;\u00B7\u00BEA\u00C8\u009A\u00BBI\x04\x01\x17\x04\u00C9\x7F$W\u00D2$\u0099tW\u00BE|\u009E o\u00C0GB=Y\u00C5\u00AE\u00B7\u0094??5C\x1C\u00FDW\u00BB\u00BC\u00CC\u00A5\u00A2\u008CO\u0092\u00A8RL\u00CD\x0B%'Eo\u00F5\x1A\u00FCP\u00B2\u00A3\u00D4\x16ju\x16\x15\u00BE\u008Ar\u00B9\u00B2u\fS\u00F0f\x04J$\r\u00B0\f^$\r\x04\x01\u0092T\x10@p\u00FE\t\u00CE\u009E\u0092\x13\u0082\u0080 \bJ\u00CF\u00A0\u00AF\u00BC\u00CCe \u00F6\u0094\u008B\u00F9Q\x18H\x00\b\nJ\u00BABi\u00C3\x17R\u00A2j\u00B6\u00A5\x16M\u0083-\u00EE\u00EF\u00A1PW,0B\u00D0\x1B\u00DC`0BX\rrr\u0097\u00AA\u0089A\u00B7] \n4\u0088\u00F9\u00ED1C\u00A1?\u00B0\u00FC0\u00B9TE=\u00A1\u0088\u00A67\u0082\u00A4\u00C2\u00E8\u009F\u009B\bM\u00D1u,d\ruTU\u00BF;\u0081\u00E2&\u00B7\u00B6Z\u00D7\x1FD\u0088\x0F\u00B2\u009BSOR\u00BF]7'\u008A*{\u00E0?\u00BA\x06AV\u00FFf\u0083\u00C8\u00FC\u00B8\u00DAH\u00CD\u00B6\u00D2\u0080\u00D07%L%/$\u00CE\u00F8\u008F\u00A6jj\u00FC\u00C4\u0094\u0080\u00A3\u00A8\x10\u00C0'\x10\u00B5c%\u00AB\u0092\u00F8\x18\u00A2\u00AAf\x1Bj\u00F9*\x04\u00BB\u00E1ca)|\"\u00AA\u00E2\u00A4g\u00AC\u00E3\u008E\u0080\x0B\u0085\u008A\u00A4\n\u00E4\u00F3\u00CB\u00CD\x00I\x1B\bY\x03\u00CA\x0B\u00B2\u0088\x02\u0091nZ\u00F7\x1Fb\u00BE\u00F8\u0099\u00F5\u008FM{\u00F0\u00D14\x14$\u00F5\"\u0099\u0096\u0080\u00A9(\u00A3\u0091\u00B0Z\u00C9\x1A\u00B2\u00A8\u00EA\u00B7\u00F0?.\u00BC\u00AA\x10 Q5j\r\u00A6\u008C\x16\x1E@\x00$\u00F5\u00B8\f\u00F6\u00BE\u00C9\x12\u00D6_\x19\u008D\u00C4\u0092\u008D\u00E0\u0081\u00E2S@H\u008D\u00D0\x03\u00FE\x1Ft\u0085\u008C\u00A8\u00D88\x12\u00D32%\u00E4\x19\x1E\x1A\u00A2\u00A3\u00A9\u009E\u00FE\u00EE.\r\u008A\x030\x06\x12;\x11\u00D118\u00ECv\x06\u00FAz=\u00D2b\x11\x1D\x0E\u00AC\u00BD=\u00A1\u00BD\u0087\u00A3\u00BAD\u009F/\u008C\u008B\u008Bgp`\x00\u009B\u00B5_\u00EA\u00A7\u00E2\u00C2\u00BC\u0080\u00D6\u00AD\u0083\u008C\u00B4d\u00A2\"\"\u00B8RV\u0081 \u00B3\t\x10\u00A6\x0BcBN&\u00A5\u00E5\u0095\x01\u0099r%\u008F\\d\u00A6\u00A7\u00D2\u00D6\u00DEN\u00BFu@FP^\u0089Ao 3-\u0085\u00F2\u00AA\x1AmF\u00FD\u00A4\u00FB\u00E6JSd\"\u00AAZ\u00BF(E\u00DA-\u0093\u00C8\u00DB\u00B8\u008DIs\x16\u00B8>sV\u00DC\u00C9\u00D6o~\u009F\u00B5\x0F?\u008692J\u009B.m\u0081J\u0082Yy\u00CB\u00C9\u009D5G\u00A2dV\u00DEr\u00A6\u00CE_t\u00E3\x02\u008DLt]p\u00D7&\u00B2\u00A6L\u00F7\x15\r0\u00F0\u00CB%\u00E4\u00DF1\u008Fm\u009B\u00D6)\x16\u008F\u008C\b\u00E7\u00D5\u00DF?\u00ABU\u00B9b\u00FA\u00F7\u00BF\u00FD\x04S'MT\u00B4#\u0087\u00A4\u00C4x\u009E\u00FB\u00D9S\x01\u0095\x19\x0B\u00F4cU\u00D0RS\u00C5\u00FEW\u00FF I3\x18M,\u00BAg3\u00AB\x1F\u00FC\x12\u00BB_x\x0E\u00ED\u009B\u008FjC}\r\u0093\x11M\u00DD\u00BC\x16\x06\u00A9\u00F8+\x1B]\u00E5\x05\u00E5\u00A2\u00A0[\u0089\u00F6\r\u00D9\u00E0\u00CBh\u0087\u00C9h\b\u00AA\u009C\u00AAW!t\u00D9\u00FF\x185\u0088\u00D9\u00DB\u00F0\u00A0\u008D#\u00BB^'2:\u0086\u00D4\u00F1\u00B9\x01*\u0094\u00B3\u00A1\u008D\u00A4\u00A7\u00DE\x7F\u0097s\u0085\x07U\u00E4\x02])\u00F0oV]&\u00B4\u00E3N\u00EF\u009C\u00DE\u00BE~Vl\u00DE\x1E\u00AC:\t\u008CF\u00A36\u00C1P\"\u0080\u00E6\u00D1\x075\u008C\u00D4\x00\u0087\u00C3A}y)\u0096\u00CC\x1C\x1A*\u00CA$y\u00B1\u0096\x14\u00E2,)\u0084\u0085\u0085\u00D1\u00DE\u00DC@GS\x03 `4\u0087\x0308`\x05\u00C0h\x0E',L\u00C0f\u00B5\x12\u0097\u009CJ|r\x1A-uU8\u00EC\x0E\ff3\u00A6\u00F0\b\u00A2b\u00E3\x01\u00E8\u00EB\u00EE@\u00AF7 \u008A\"\u00F6\u00E1a\x0Fk\u00CE\u009A\u008D\u008BK >%\x15\u009D^OgK3\u00ED\u008D\u00F5>>\x1B\u008C&tz=\x03\u00FD}\u0092\u00B2\u009Ea\u00C1\x1C\x11\u0089\u00DDng\u00C86\u00E0S\u00DE\x1Bq\u0096Tb-\x16\x04\x04\u00DA\u009A\x1A\u00E8lnt\u00D5\u00CBY\u00CF~\x10\u00C0h\nG\x10\x04l\u00D6~\u00E2S\u00D2\u0088ON\u00A5\u00EA\u00F2y\u00BF\u00FA\x05 *2\u0082\u009E\u009E^\u009F<\u00A3\u00C1\u00C0\u008C\u00A9\x13\u00B1$\u00C6c\u00B5\u00DA8\x7F\u00B9\u0094\u00F6\u008EN\x00\u0092\x12\u00E2\u00E9\u00EC\u00EAfpx\u00D8\u00E7\u00C6\u00A7\u00A7&3eb.z\u00BD\u008E\u0086\u00A6\x16.^\u00BE\u0086\u00DD\u00EEn\u00CF\u0088p3\u00B11\u00D1X\x12\x13\u00D0\u00E9t\u00A4\u00A5X\x10\u0081\u009E\u00DE>zz\u009D\u00ED\u0096\u009D\u0091\u00CE\u00B4)\x13i\u00EF\u00E8\u00A0\u00F8\u00CC\x05\u00ECv\u00BB\u00DF\u00BA\u00F8\u0083W\u00D7\x1FZ\u00BAz\u00CF',\u00999,\u00DE\u00B8\x15\u00A39\u009C\u00E6\u009A*\x00\u00E6\u00AF\u00B9\x07\u009B\u00D5J\u00D1\u009E\u00BF\u0091v\u008Bs\u009Ct\u00FA\u0083\u00F7\x00\u0098\u00B1h)\u00D1q\tD\u008C\u008B&.9\u0095\u0096\u00BAj&\u00CD\u0099Ot|\x12\u00A6\u00F0\b\x1C\x0E\x07\x13o\u009B\x0F\u00C0\u00CE\u00DF=\u00CB\u00ECek\x18\x1C\u00B0r\u00FA\u00D0>W}b\x13-\u00E4\u00AD\u00DFLL\u00A2\u0085\u00A6\u009AJDQ$!%\r\u00FB\u00F00\u00C7\u00DE\u00DDIc\u00D5u\u0097\x7F9\u00D3g\u0091\u009A\u0093K\u00C1\u00DF^\u00F3\u00AA\u0089\u00BB\x0F\u00BB}\u00EDz\u00DA\x1A\u00EB\u00B9XT\u00A0\u00B8\u009C\u0096\u009C5\u009E\u00BC\u00F5[0\u0098L4\u00D7V#\x00\u00F3\u00D7\u00AEg\u00A0\u00AF\u0097\u00E3{v\u0091\u0096;i\u00A4\u009E{\u00DD\u00F5\u008CO$\":\u00868K2-\u00B5\u00D5\u00D4^\u00BB\u00EC\u00B7}###x\u00E7\u00E5\u00DF1\x7F\u00CD\x16\u00B7\u00A7\u0082\u00C0\u0083[6\u00B0\u00FD\u00FE{\u00A9\u00AA\u00AD\u00A7\u00B6\u00BE\u0091\u00E8qQ<\u00F5\u009D\u00AFr\u00F2t\t\u00CF\u00FC\u00F6\u008F<\u00F7\u00F4\u00F7\u00F8\u00C1\x7F\u00FD\u0086\u00AB\u00E5\x15n\u009F\u0093\x12\u00F8\u00CD\u00CF\u009Eb\u00CA\u00C4\\\u00CE]\u00B8L\u00BFu\u0080\u00F1Y\x19$\u00C4\u00C5\u00F2\u00D3_\u00FD\u009E\u00C2\u00E3\u00C5\x00,\u009C?\u0087o<\u00F6\b:]\x18\u0089\u00F1q<\u00FF\u00CB\u009F\x00\u00B0\u00E3\u00CD\u00DD\u00ECx\u00EB\x1D\u00BE\u00F2\u00F0\x03l\u00D9p'\u00C5g\u00CF\u0093\u0095\u0091\u0086(\u008A|\u00F9\u009B\u00FFN\x7F\u00BF\u00D5o}|\u00E01t\u00D08F\u00D5>0\x1F\x1DO\u0086\u00E9t\u00A4O\u0098D\u00D9[\u00A7\x00H\u00CB\u009D\u00C4\u00CAm\u00DB9\u00F6\u00EEN\u00CAKN;Y,\x00\u0082\u00C0\u0084[\u00E7\u00B1\u00FA\u00B3_\u00A0\u00BD\u00B1\u009E\u0086\u00CAr\u0089\u00AE\t\u00B7\u00CD\u00A3\u00BC\u00E44\u00FB\x7F\u00F1cI\u00A4\u00BC\u00E3\u00AE{\u00E9\u00E9l\u00E7\u00E2\u00F1\x02E\u00DF\u00E2,)\u00AC{\u00E4q\u00CE\x15~\u00C0\u00A5?=\u008FCt\u00B8rs\u00A6\u00CEd\u00D5\u00B6\u00ED|\u00F8\u00B7\u00BFP\u00E3M\n\u00D9\u00B1\u0095\u00BF\x01\u00973?}\u00C2d\u0096oy\u0090c\u00EF\u00EE\u00E4\u00FA\u0085\u00B3\u00CEz\u008A\"\b\x02\x13g\u00CFg\u00CD\u0083\u008F\u00D2Z_#y@\x10\u009C\u00F5\u00BCv\u00E6\x14\u00EF\u00FD\u00E9\x7Fp\u00D8\u00EDR[\x1E\u00D3t\u00F9q\u00AF\u00DB\u00B7\u00EF}\u00EBq&\u008E\u00CF\u00E6K\u00DF\u00FA\x1E\x15U\u00B5\u008C\u009E\u00C9\u008B\u008A\u008C\u00E0\u00AB_|\u0090?\u00FC\u00E2\u00C7\x18\f\u00BE\u00B7\u00FD\u009B\u008F=\u00C2\u008E\u009D\u00BB\u00F9\u00D6\u00F7\u009Ef\u00C8\u00A3\u009Do\u009F=\u008Bg~\u00F8$\u008F\x7F\u00E7?\u00B8t\u00F5\x1A\x07\x0B\u008Eq\u00B0\u00E0\x18i)\x16\u009E\u00FF\u00C5OX\u00FF\u00C0\u00A3.\x7F\u00D2SS\u00B8\u00FF\u00BE{\u00B8\u00EF\u00E1'\u00E8\u00E8\u00ECD\x10\x04\u009E{\u00FA)\u00EE\u00BBg-\u00AF\u00FCu\u0097J\u00DB\u00F9\u00C7\u00D8\u00D6Q\x15\u00F8k0\u0099Y\u00BCi\x1B}\u00DD]4T\u0096\u00A37\x18X\u00FE\u0099\u00878\u00FC\u00E6+\u0094\u009F\u00FBH\x1AjE\u0091\u00B2\u00B3\u00C5\x14\u00EC\u00FC\x0B\u00A9\u00E3'\u00F8\u00E8\u00B2\u00F5\u00F7Q\u00F8\u00F6\u00EB^\u00DD\u00B9\x06\u00C7\x04\u0081\u00A5\u00F7=\u00C0\u0099\u00C3\u00FB\u00B9P\u00F4\u00A1\u0084\u00A4\x00\u0095\u0097\u00CF\u00F3\u00FE\u00EB/\u0091\u00BFq+\u00A6\u00F0p\u00F9\u00BA\x05\u00B8\u00D6i0\u009AX\u00B6\u00F9s|\u00F0\u00C6\u009F\u00B9~\u00FE\u008C\u00BB\u009E\x02\u0088\u00A2H\u00E9\u00E9\u0093\x14\u00FCm\u0087\u00AB\u00E7\u00F0\u00D4g\u00ED\u00ED\u00E1\u00E8;\x7F\x1D!i\u0080\x18Q\u00B3l\u00D1\u00ED\u00CC\u009D5\u009D'\u009E\u00FC\u00E1\bI\u00DD\u00E8\u00ED\u00EB\u00E7?\x7F\u00FD\x02%\u0097\u00AE\u0092\u009Al\u00F1QQ|\u00F6<\u00BF~\u00E1e\tI\x01N\u009E)\u00E1\u00A5\x1Do\u00F1\u00C8g7\u00AB\u00DA\x06\u00C8HK\u00A1\u00BA\u00B6\u009E\u008E\u00CE.\u00C0Y\u00E77\u00DF\u00D9\u008B^\u00AF\u00F7\x15VR\u00A2\x00\u00F5\u0088\u00AAa$\u0090\u0094\u0091\u00CD\u009A\x07\x1Fu\u008A\x0B\x02\u00E6\u00C8q\u00C4\u00A7\u00A4\u00D1Pq\u008D\x03\u00AF\u00BE\b\u00A2H\u00F6\u00D4Yt\u00B64SS\u00AA\u00DC\u009DU]\u00B9 \u008D2#\u00A8\u00BB~\r\u00FB\u00D0\u0090\u00BCc*\u00FE%gd\x13\x1E\x19\u00C5\u0095\u00E2\"\u0099\u0092\u00CE\u00BFMU\u0095\\<^H\\R\nM\u00D5\u0095\u00F2\u00EA|\x02\u00A9\u008C\u00D4HR\u00F6\u00B4Y\u00B45\u00D4Q_^\u00AA\u00A8\u00A4\u00F2\u00D2yZj\u00AB}T\u00D4\u0095]a\u00D8\u00A7\u009E\u0081a\u00F3\u00FA\u00B5\u00BC\u00F8\u00EA\u009B\u00F4\u00F6\u00F5K3<\u00EA\u00F0\u00BB\u00FF\u00DD\u00C1\u00BA\u00D5\u00CB|\u00CA\u00EE;tDQ\u00EF\u0081\u00C3Gyh\u00EB&\u00BF\u00F6\u00ABj\u00EA\u00C8\x1D\u009F\u00C5\u00DC[g\u00F0\u00D19\u00E7\x18\u00BB\u00E0\u00D8I\n\u008E\u009D\u00D4\u00E4\u00BF\u00DAZ\u00EA\u0098\u0097\u00A7\u00FA\u00BA:(=}\u00C2\u00F5}\u00D0\u00DAOW[\u00ABs\u00C1\x7F\u00E4\x06&\u00A6e\u00C8\u00DC<_4\\\u00BF&q\x11\u00C0\u00DA\u00D3\x1D\u0094_\ti\x19\u00D4]\u00BF\u0086\u00C3\u00E1\u008E\u00A4r{F%G\x0E\u00F9\u00A4\u00F9t\u00B0\x1A\u0097Y\u0092\u00D23\u00A9\u00AF\u00B8&\u009B\u00E7\u00A9\u00A2\u00FE\u00BA\u00AF\u008C\u00B5\u00D7wB\x14(\u00A6O\u009E\u00C0\u008F~\u00FE[U\u0099\u0096\u00B6v*\u00BD\u00A2-@sk\u009Bb\u0099\u0086\u00C6fb\u00A2\u00C7a\u00D0\u00EB}\"\u00AE'\x1A\u009B[x\u00F6\u00BF_\u00E4WO\x7F\u009F\u00D2\u00B2\u00EB\u00BC\u00F7A\x01\u00BB\u00F7\x1Ed\u00C0f\u00D3^\t\x05\u008C\u0099\u00A8\u00FD=\u00DDT^*q}\u0097[\u00F3\u00D4\x1BM\u00F4\u00F7z\x11NnYkh\b\u009D\u00C1\u00A0\u0098\u00EF\u00AF\u00BC'\fF#C\u0083\u00EE\x06\u00D2\u00BAc.\b\u00A35P^\x05U\u00F2G\u00A770<8\u00A8\u0098?\u00AAnh\u00D0F\u0098N'\u00C9\x1E\x1A\x1A\u00FB\u00CD4\u0099\u008C\u00D8l\n\u00F6=\u00D0?\u00E0\u00BBb1<\u00AC<\u00E4p\u008C\fa\u00CCf\x13C\u00BD\u00BED\u00F5|\bw\u00ED9\u00C0\u00FEC\u0085,\u00BEc\x1E\u00AB\u0096\u00E6\u00B1\u00FD\u0081\u00CD<\u00F1\u00ED\u00A7\u00A8\u00AA\u00AD\u00D3T\x07%\u0084\u008D\x1A\u00BA\u0091\u00E8no!\u00CE\u0092\u00AA\u0090\u00EB\u00B6\x1EgI\u0091MW\u0092WCOg;\u00B1I\u00C9#%\u0094\u00CB\u0098#\"1\u009A\u00CD\x00\f\u00DA\x060GDzX\u00F2(7r\u00A97(/\u008C\u00F7t\u00B4\x11\u009F\u0092\u00E6\u00D7\u00EF\u00B8\u00E4T\u00D9t%y\u00AD\u00A8\u00ABo\"7;SUF\u00A7\u00D3\u0091\u0093\u0099\x1E\u00A4\x05m\u00E8\u00B7\x0E\u00B0\u00FFP!\u00FF\u00FA\u0083\u009F\u00F1\u00F2k;\u00F9\u00FA\u00E3\u008F\u008CY\u00E7\x18&S~\x1A\u00D8#\u00BB\u00F2R\t\u00E3\u00A7\u00DF\u00A6\u00B2\u00A5\n\u00E1Q\u00E3\u00C8\u00996+xw\u00BC\u00FC\u00A9+/%)-\u0083x\t\u00F9\u00A5\u00D0\u00E9\u00F5l\u00F8\u00F2\u00D7\u0089ItN.\u00DA\x1A\u00EAHJ\u00CF\u0092D;O\u00AD\u0082 \u0090\u0094\u009E%k\x0F\u009C\u00E3\u00CF\u009Ci\u00B7b\u00F2 \u00BB7\"\u00A3c\u00C8\u0099:\u00D3\x7Fu\u00BC\u00A1\u00B0\x14\u00E6)p\u00F8\u00D8I>\u00B3\u00F1NU5w\u00AF^JTdD\u00E0\u00F65`\u00FB\x03\u009B\u00C9_8_\u0092VT|\u0086\u00E9\u0093\x03\u00DB\u009E\u0095\u0083\x06\u00A2j\x7F\u00EE\u0094${\u00DA\u00DB(=s\u0082\u0095\u00F7o\u00C7`4\u00F9\u00E4\x1B\u00CDfV\u00DE\u00BF\x1D\u0087c\u00EC\x0B\u00C3\u00A3\u008E\u00D8\u00AC\u00FD\u009C-<\u00C8\u008A\u00AD\x0F\x13\x15\x13\u00EB#\u00A23\u00E8Yz\u00DF\x034T\u0096\u00D3RW\r\x02\u00F4vv\u00D0\u00D1\u00DC\u00C8\u00CC\u00BCeRe#\u0098\u0091\u00B7\u0094\u00A8\u00D88E\u00B3]\u00AD\u00CDT\\8\u00C3\u008A\u00AD\u009FG/\u00B3\u00D3c\n\u008F`\u00E5\u00FD\u008F :\x1C2\u00A5\u00B5C\u00A9\u009D_y\u00E3mfN\u009D\u00CC\u00FD\u0092\u00F3\x01n\u00E9\u00A9\x13s\u00F9\u00E7G?O_0k\u009A\x1A\u00A0\u00D3\u0085q\u00E7\u008A%\u0092\u00B4[\u00B23\u00A9\u00A8\u00F6>\u00B8\x128\u00C6<F\u00D5\u008A\x13{\u00DF&o\u00C3g\u00D8\u00F2\u008D\u00EFr\u00E9\u00F8\x11Z\u00EBk\x10E\u0091\u00A4\u008C,\u00A6\u00DF\u0091OCE9M#\u00B3\u00FE\u0090l\u00D7\x03%G\x0Fc4\u0099\u00D9\u00F8\u00D8\u00B7(=}\u0082\u00FA\u008A2\u00EC\u00C3C$\u00A6e2u\u00FE\"\u009Ak\u00AB8\u00FA\u00F7\u00B7\u00DC\n\x05\u0091\u00C2\u00B7_\u00E7\u00AE\u0087\x1F#>9\u0095\u008A\x0B\u00E7\x18\u00E8\u00EF\u00C3\x1C\x15\u00C5\u00F8\u00E9\u00B7\u0092\u0094\u009EESu\u0085\u00B2A\x01\u008A\u00F6\u00EC\"\x7F\u00E3V6\x7F\u00EDI.\u009F8J[C\u00AD\u00AB\u009E\u00D3\x16\u00E4S{\u00ED\u00B2\u00BA\x0E/L\u00CA\u00CD\u00E1\u00D1\x07?\u00E3\u0093^YSGQ\u00F1YIZwo\x1F\u00FF\u00F4o?\u00E2\u00D9\x1F>\u00C9\u0092\u0085\u00F3\u00D9s\u00B0\u0080\u00FA\u00C6&\"\u00C3\u00C3Y\u00BC`.w\u00AE\u00C8\u00E7\u0099\u00DF\u00BE\u00C8\u00C3\u00F7\u00DF\u0087\u00A8\u00FA\u00DAupx\u00F3\u009D\u00F7\u00D8\u00F1\u00C2/\u00F9\u0097\u00AF=J\u00C1\u00B1\u0093X\u0092\x12x|\u00FB\u00E7\u00F8\u00EE\u008F\u009F\x19\u00B3n]L\u00DA\u00D4\x1F\u00B8\u00EF\u00BB\x17\x03\x04\u00994\u008F\u00CC0\u00BD\u009E\u00C1\x01+m\u00F5\u00B5\x1E\u00A5\u00E5\u0097\u008EDQ\u00A4\u00FA\u00CA\x05\u009Ak*I\u00C9\u00BE\u0085\u00EC\u00A93H\u00C9\x1A\u008F\u00C3\u00E1\u00E0\u00F4\u00A1\u00FD\\8v\u00980\u009D\u008E\u00BE\u00EENz\u00DA[A\x10\u00D0\x19\f\u00F4uw\u00D1\u00D5\u00DA,uJ\x00\u009D\u00C1@OG;\u00BD\u009D\x1D\u00AEt\u009D\u00C1@oG\x07\u00DD\x1D\u00AD.\u00E9\u0086\u008ArjJ/\u0091\u0090\u0092F\u00F6\u0094\u00E9\u00A4\u008D\u009F\x00\x02\u009C+8\u00C8\u00C5\u00E3\u0085>7l\u00D0j\u00A5\u00F4\u00CC)\u00CC\x11\u0091dO\u0099N\u00C6\u00C4)D'$\u00D1Xu\u009D#\u00EF\u00BC\u00C1\u0090m\u0080\u00AE\u00B6V\u0097]\u00BD\u00D1Dgs#\u00FD=#k\u0087\x0E\u0091\u00AA\u00CB\u00E7i\u00AD\u00AB!%;\u0097\u00AC)\u00D3\u00B1d\u00E5\u00E0\u00B0;8}p/\x17O\x1CA\x10\x04\u00FA\u00BA;\u00E9nw\u00FA\u00A9\u00D3;\u00EB\u00D9\u00DD\u00D6*\u00F1\u00C5h\u00D0c2\x191\x19G>\x06\u00F7uOo/W\u00CB+\u00890\u0087K\b\u00DB\u00D5\u00DD\u00C3\u00AE=\u00EF\u00E3\x10\x1D,\u009A?\u009B\u00FC\x05\u00F3\u00C8\u00CD\u00C9\u00A4\u00AA\u00B6\u009E\u009F>\u00F7<\x17\u00AF\u0096\u00F1\u00C4\x17>\u00CB\x0B/\u00BF\u008Emd\u00E2\x17\x1E\x1E\u00CE\u00D5\u00B2\u00EBt\u00CBl\u00C5\u008Eb\u00DC\u00B8H\u008A\u008A\u00CF\u00B8\u00B6C\x05A\u00C0\u00A0\u00D7s\u00BA\u00E4\u0082K\u00C6f\x1B\u00E4\u00BD\u0083\x05\u00CC\u009A:\u0099\u00D5\u00CB\x17\u0093\x18\x1F\u00C7\u00CF\x7F\u00FB\"\u00E7/]U\u00D4\u00AB\x15B\u00D6\u00BC{\u00C5`\u0089*+\u00AE\u00B8\u00C6)+,\u00AB\u00DFiV\u00BB]\x1F=\x12\x17\u0094\u00D6=\u00E5\u0094(\u00FF\u0080CH~\u00BCATZG\x10\x15\u00D4)\u00FFp\u0083\u009C\u00E8\u0092\u0085\u00F3\u00C8\u00BB}\x0E?}\u00EEy\u00DF\u00CC\u0091\x02\u009B\u00EEZ\u00C5\u0086;W\u00F0\u0085\u00AF\x7F\u00D7[\u00A5\u00BCMWR\u00A8~\u0090\"\u00B8\x1F\u00A3\b\u00D1\t\u00FFO&B\u00D5\u00B9\u00DD\u00B8\u00C3u\u00A1\u00C5\u0089\u00D3\u00E7\u00B8m\u00C6\x14\u00BE\u00F2\u00F9m\u00AEe6OL\u009E0\u009E\u00AF}\u00F9!~\u00F7\u00D2\u008E\u008F\u00C1\u00BB\u00B1\u00E1S\x1DQ\u009D\u0097c\u008F\u00A8\u00A2\u00D6\u00E8\u00E0J\u00FAx\"*\u0088X\x12\x13\u00F8\u00F9\u008F\u009E\u00A4\u00B7\u00AF\u009F\u00D7w\u00ED\u00A5\u00BC\u00A2\u008A\u0098\u00E8(\u0096\u00E5-`\u00D3]\u00AB\u00F8\u00D5\u00F3\u00FF\u00C7\u00DF\u00F7\x1F\u00C6'\u0082}\u00C2#\u00EA'\u0092\u00A8\u0080lD\u0090\u00C8\u00AB\u00E9\u00F7GT%\u00B3J\u00FC\n\u00B2\u00D1}\u00F4(N`BGTp\u00AE\u0095\u00AE[\u00B5\u0084\u0095\u00F9\x0B\u00C9JO\u00A5\u00A7\u00B7\u008FSg\u00CF\u00F3\u00D7\u00B7\u00F7\u00D2\u00DC\u00D2&Q\u00F6)\"\u00AAL\u00FAh\u009Al\u00B0\u00FA\x04\x10\u00D5Gl,K\u00DBJ\u00E3S\u0099\u0084\u009BDT\u00D9\u00B8\u00ACH&u\u00DD\u00FF(D\x1D\u00C3\x185\u00D0F\u00BF\u00D1P\u00EDTC\u00AC5\x14\u009A\x03\u0084\u009F\u0087\u00E0\x1Fg$\x1D\x1C\u00C2\u00E0fU1\u00D0\x06\x1E\u00E3\r\u0091<\u00D0\u00C1\u00D5P\u00B9\u00CB\u00D7h\u00F8\u0086\u00A4\u0087\x0E~\u00B9\u00FF\t\u00C2\u00C77\u00EB\u00F7\u00D78A\u00E5\u00AB\u00C5\u00BF\u00C0\u00EE\u0086\u00BA\u00BCR\u00F7\x18X\u0091\u0080\u00F2?\u00C1Pu=D\u00F5\u00BAi;S\u0081B$\x04\u0087&<\u0094\u00A4X\u00E2i\u00EF\u00E8ahh\u00C8\u008Ff_\u008A.]p+\x1F\x1E?'+\u009D7\x7F\x06GO9\x17\u00BD\u00C3\u00C2\x04\u00F2o\u009FETd8aB\x18UuM\u0094\\v\u00BE\u00B1p\u00C7\u00DC\u00E9\u008C\u008B\u008C \"\u00C2L\x7F\u00FF\x00UuM8\x1C\x0E\u00AEU8\u00B7\x17\u00CD&#\u00CB\x17\u00CDF\b\x13\u00D0\u0085\u0085Qr\u00A9\u008C\u00AA\u00BA&\x00\u00B2\u00D3\u0093\u00D1\u00EB\u00F5\u0094WJO eg$SU\u00DB\u00E4\u00FA\x1E\x1F\x17\u00CD\u00A2\u00B93\u00B0;\x1C\u00B4\u00B5wq\u00F2\u00AC\u00FB\u00FC\u00AF\u00C1\u00A0gE\u00DE\\t\u00BA0t:\x1D\u0097\u00AFUp\u00AD\u00C2\u00B9Q\u0093jI\u00A0\u00A7\u00CF\u00EA:\u00C7j4\x1AH\u00B5$\u0090\u009B\u0093\u008EA\u00AF'\"\u00DCL\x7F\u00BF\u0095+eU\x00T\u00D56\u00BAt\u00AE\u00CC\u009F\u0087 \b\u00E8u:.\u0095VP6\u00A23*2\u0082qQ\x1144\u00BA71&\u00DE\u0092IUm\x03\u00EBV.\u00C2:`s\u00DD\u00A3\u0083\u0085\u00C5\f\x0F\u00AB\u009F\u00C5U\u008F\u00A8\x1F\u00FBS\x1E\u00CC8X~\u00B0\u009E\u0093\u009E\u008C\u00D9d@\u00C4I\u00C5\u00D1\x7F\u00A4\u00DF\u00E4g\u00D3\x0Fl\\\u0081%!V\u00AA\x10HKN\u00E4\u00EE\x15w\u0080\b\u00E1f\x13_\u00BC\x7F\x1D\u0097\u00AFU\u00F1\u00EE\u00C1\u00E3\u00EC~\u00FF\x18\u0083CC<\u00B4y\r R\u00F4\u00D1E\u00F6\x17\u009CB\u00AF\x0Bc\x7F\u00C1)\u00AE\u0096Ws\u00EB4\u00E7\x1B\u00BA\x19\u00A9Il\u00DB\u00B0\u0082\x0F\u008F\u009Fe\u00CF\u00C1\u00E3\u00EC>p\u008C\u00F1Yi\u00AC]v;\x00\u0093'dq\u00D7\u00F2\x05\u0084\u009B\u00A5\u00E7$&\u00E7fK\u00BE\u00A7$\u00C5s\u00BD\u00BA\u009E\u00BD\x1F\x1C\u00A7\u00BD\u00B3\u0087\u00B5\u00CB\x16\x00\u0090\x14\x1F\u00CBC[\u00EE\u00E4\u00E8\u00A9\x12\u00F6\x1C,b\u00F7\u00FE#$%\u00C4\u00B2qm>\x00\u00D9\u0099\u00A9\u00C4\u00C6\u00B8\x0F\f\u0099MF\u00A6L\u00C8\u00E6\u0083#\x1F\u00B1\u00EF\u00F0\t\u00F4:\x1D\u00FB\x0E\u009F\u00A0\u00AA\u00B6\u0091)\x13\u009C6-\u0089q<\u00BCu\x1D\u0085\u00C7\u00CF\u00B2\u00E7\u00FDc\u00BC\u00B3\u00AF\x10Kb<\x1BFt\u00C6\u00C6D\u0091\u0093)=1w\u00DB\u008CI\u0098MF\u00AC\x036\u00F6\x1D:\u00EE\u00FA\f\u008F\u009CqU\u009B\u0090\u008D\u00AD\u00EB\x0F\x19\u0091\x15\u00D7\u0085B\u00A3Ot'\u00CD\u009B5\u0099\u00D5\u00F9sY\u00B2`\x16\u0082 \x10n6\x11\x1F\x1B-\x11\u00CFHM\u0092\u00949x\u00F44+\x17\u00CF\u00F1\u00D1\u00BBl\u00A1;\u00D2n\\\u0093\u00C7\u009F\u00DF\u00DAOs[\u00A7+\u00FFJY5\x1F\x16\u009Deu\u00FE<UoW/\u0099\u00CF\u009F\u00DEx\u008F~\u00AB\u00FBL\u00EA\u00E1\u00A23\f\r\u00DB\u00C9\u00CEp\u009E\u00FEz\u00FD\u009D\x0F\u00D8\u00BAa\u0085\u00A6\u00EA\x02\u0094U\u00D6\x12\x1B\u00ED$\u00DF\u00DD\u00AB\x16\u00F1\u00D2k\u00EF\u00D2\u00DB\u00E7>\u008CRT|\u0081\u00E6\u00B6\x0E\u00A6M\x1A\u00AF\u00EA\u009B\x12\u00EE^\u0095\u00C7\x1Fw\u00EC\u00A6\u00CFC\u00E7\u00B1S%\u00B4ut\u00AB\u00E8\f~<\u00AE\u0091\u00A8\u00DA\rH\x16\x194/\u00E7\x04fU\u0092\u00AB(\u00E4\u009B\u00B1e\u00DD\x12\x1A\u009A\u00DA8P\u00F8\x11W\u00CA\u00AAyx\u00CB\x1A\x06\x06\x07Y\u009D?\u00D7%3\u00F9\u0096LR\u0093\u00E2\u00A5\u009A\x1C\"\u00ED\u009D\u00DD\x1EQ\x15,\t\u00B1\u00D47\u00B6!:\u009Cv\u00EC\x0E;\x032\u0087\u0096\u00AB\u00EB\u009B\u0089\u0089V>\u00DE\x18\x1F\x1B\u00ED\u00EAJ\u00BD}?t\u00F44\u00B7\u00DF6\x15D\u00B0\r\x0EQT|\u009Ee\u008B\u00E6\u00F8*\u00F1\u00AA\u00AB\u00C9h`\u00D1\u00BC\u009944\u00B7b6\x19i\u00EB\u00E8\u0096]\x1A+*\u00BE\u00C0\u00CC\u00A9\u009E\u00BF\u00BB\u00A0\u00ED>GF\u0098ii\u00EB@\x14}O\u0081\x1D=y\u008EY\u00D3\u00BC\x7F\u00CBa\u00EC\u00F0\"\u00EA\u00C7\u00DE\u00D7\u00CB@\u00C3\u00A4F#YK.WP\u00D7\u00D8\n\"4\u00B7vRx\u00E2<\u00B7N\u00C9\u00C5\u00E1p\u00A0\u00D7\u00E9@tF\u00DCS\u00E7\u00BC\x0FQ\u0088\u00BC\x7F\u00E44\u00CB\x17\u00CDv\u00A5\u00AC\\<\u00C7c\u00DC*b\u00B7+\x1D\u00DD\x13q8\u0094\u00EB\u0090\x10\x17Mk{\u0097|IQ\u0094\u00BC\u0094Xz\u00BD\u0086\u00A8\u00C8pR\u0093\x13\x14\u00F5-\u009C7\u0083\u00A5\x0Bg\u0093\u009A\u009C\u0080\u00D1\u00A0'&:\u008A\u00CE\u00AE\x1E\x1F\u009FF\u00E1\u00F7\u009D{\x19\u00D7\u00A3\u00C7E\u00D2\u00E1\u00A3\u00D3\u008D\u00C1A\u00F5\u00F1\u00E6\u00EC\u0099\u0093Y\u00BB\u00FC\x0E\u00D7\u00C7\u00FD\u00F2\u009F\u00B2m\u00FD\u00E8\u0084#$\u0093\u0097`\u00E02,\u00EF\u00C1\u00C8\u009B\u00C6c4\u00E0\u00C4\u00F5\u00EA\x06INM}\x0Bk\u0096\u00CC\u00E5\u00C3\u00A2s,_x\x1B'\u00CF^\u00A1\u00B3\u00ABW\u00B6\u00AC\u00DDn\u00A7\u00BB\u00B7\u009F\u00B8\u0098q\x18\u00F4:Z\u00DB\u00BB$QJ\u00AF\u0097\u00BEZ\u00E2\u00E9\u00BF\u00FC\u00CF\u00E58\u00CB\u00D6\u00D45s\u00F7\u00AA\u0085\u0094\\*\u00F7\u0091\u0088\x19\x17\u00C9\u00E0\u00A0\u00F4\u00D5\u008F\u00DD\x07\u008E\u00F2\u00A5\u00CF\u00DE\u00C3K\u00AF\u00ED\u0091\u00B5WT|\u0081K\u00A5\u0095\x00l\u00BA3\u009F\u00DE\u00BE~\u00D2R\x12e\u00AD\u009BM\u00C6\u00A0bSsK\x07\u008F}\u00FE>\u00E2c\u00C7a\u00B3\r\x11\x19\x11N\u00C9\u00E52\u00CA*j1\u009B\u008C\u008A*G\x1F\u00D83\u00E7\u00AF\u00B2\u00EF\u00D0q\u00B7#!\u00E9\u00FA\u0083XVQ\u00DB\u0088\b\u00AAe\u00FC\u00FD/k4\u00AA]4w\u009A\u00E4\u00FB\u00C2\u00B9\u00D38s\u00B1\u008C\u00E6\u00B6N\u0092\u0093\u00E2Y\u00917\u009B\x03\u0085\x1F!\x19\u00A0z`\x7FA1k\u0096\u00CCc\u00E5\u00E29\x1C<rZb\u00BF\u00B1\u00B9\u008D\x19\u0093\u00BD\u00C6f\u00A2\u00C8\u00FA\u00D5\u008B8Z|\x01%\f\u00D8\x06\u00D1\u00EBt\x1E\u00E3d\u00B7\u00DD\u00CDw/\u00E3\u00C0\u0087\u00A7\u00BCk\u00CA\u009B\x7F?\u00CC\u0096{\u0096y\u008B\u00FB@\x14ED\u0087\u0088\u00CD6Dj\u00B2/Y\u00B7\u00AE_\u00C1\u00BE\u00C3'hji#\u00D5\u00E2\u008E\u00D2\u00A9\u0096\x04\u009AZ\u00DA\x15\u00F5\u00DA\x1D\x0E\u00CE_.\u00A7\u00F8\u00DCe\u00F6\x1F>\u00C1\u00CE=\u0087IKI\u00E2\u00DEuK\u00D9\u00B6q\x15\x07><ASK;\u00C9\x1EC\u00A8\u00A8\u00C8p\u00F7L\u00DF\u00BBB\x1A\x10\u0082\u00E5)\u00A5X\x1CL\u008CV\u0088\u00AA\u0080\u00A0\u00AA\u00CF\u00A3[@Y\u00CC!:X\u00BF\u00EA\x0E\u00CA\u00AB\u00EA\x19\u009F\u0099\u008Amp\u0088\u00BA\u00C6\x16\x00j\u00EA\u009B\u00C8JOfpH\u00F9\u00E58\u00BB\u00DD\u008Eu`\u0090\u00A1\u00A1\u00E1\u0091\u00E8\u00E0n\u00E9\u0082\x13%\u00AC\\<\u0087\u00C9\u00B9\u0099\u0094U\u00D6a4\u00E8\u00C9\u00CDI\u00E7Ri\u0095\u00E2\x18t\x14o\u00FE\u00FD0\u009B\u00EE\u00CA\u00C7f\x1B\u00A2\u00B2\u00A6\u009E\u00B8\u00D8hr2R\u00D8{\u00E8\u00B8\u00C7\u00B8\u00D7]\u00A6\u00B3\u00BB\u0097\u00EBU\u00F5\u00CC\u00999\u00C9G\u00D7\u00C2y3\u00C8H\u00B5\x10n61<<L\u00BF\u00D5\u00C6\u00DB\u00FB\n\u00D9\u00B0v1\x0E\u0087HeM\x03\u00D1Q\x11\u00DC\u0092\u009DF\u00C1\u0089s\u00F4\u00F4\u00F6\u00D3\u00D3\u00DB\u00CF\u00FC\u00DB\u00A6a4\u00EA\x11\x10\u00C8\u00C9L\u00E1\u0095\u00B7\u00F6\u00A1\u0086\u00B7\u00DE=\u00C4\u00BD\u00EB\u0096\"\b\x02\u00A5\u00E5\u00D5\u0088\u00A2H\u008A%\x11\u009D.\u008C\u0095\u00F9\u00F3\u00F9\u00E0H16\u00DB +\u00F2\u00E7\u00D1\u00DBge\u00CA\u0084l^\u00DFu\x00\u0093\u00C9\u00C0\u00EC\u0099\u0093%U:Xx\u00CA5\u00F3W\u0082\u00905\u00F7^\u00D1w\u00FB<\u00B0}y\u00B9\u00BEY\u00FD\u0080J\x106P\u00DB\u00FF\u0097)\u00EB%\u00AA\u00D3\u00E9p8\x1C\x18\u00F4zR,\u00F1\u00B4\u00B4uJ\u009E\u00F0\x15y\u00B3\u00B9x\u00B5\u0092\u00A6\u00D6\x0E\x14\u00A1\u00DEU\x00\u00CE\u00B5\u00D4\u00F4\u0094$\x06l6\u009A[;ee\u0094z\x01\u0083AG\u00AA%\u0081\u00EE\u009E>:\u00BB{\u00BDd\x14\u00B6 \x028?\u00A0\u00D7\u00E9HKI\u00A0\u00B7\u00CFJ[g\u00B7\u008F\u00FE\u00F8\u00D8h\u00840\u00816\u00CF1\u00B3Z\u00D7,\u008A\u00E8t:\u00D2S\u0093\u00E8\u00EE\u00E9s\u008D[\u00A3\"\u00CD\u00D8\u00ED\x0E\u00ACV\x1BQ\u0091\x11DE\u0086\u00D3\u00D8\u00DC\u00E6\u00ABG\u0094^\u00F8v\u00BE\u00EE\x14'Qa\f\u0087\u008DG\u00D2\u0095\u008A\x04|HE\u00D9\u008E\u00FA\u00F1?\u0085\u00F2\x1A\u0083\u00FA\u00E76\u00AD\u00E2\u00D5]\u00EF\u00CBgj \u00A8T^m_K\u0094\u00BD\u0094M\u00F0KR5\x7FD\u00C5uf/~(9\u00A3I\u00BF\u00DA\u00DAg \u00FAe\u00F5x$\u0086h\x0B5\u0098\u00D5\u0082\u00C0\u0096\u00AA\\\"\u009A\u00DE\u00F5\u00F1j,\rE\u00F6\u008C\x0E\u00EE\u00BD\u00D5\u0084\u0094\u00A4j\u00AAB\u00D0\u0086\u009Fb\x04H\u00D4\u00C0\x1AF\u00F2\u00AC\x04\u00C4/?\u00F1H3Ye\b\u00AB@\u00DC\u008E\u00AE^\x15\x19\u008Dl\u00F7K\u00D2\u00E0\u00DA\"p:~\n\b\u00ECU\x05\x1F\u00A2*\x05\u00E2`f\u00FF\x01{\u00A31O;YG\u00A5e\u0088\u00E6MJ\u00D9\b\u00A7\u0091\u00A0#\u00FEh\"i\u00C0yA\x16\u00F1\u00D7\u00ED\u008F\u00D5\u00BE\u00BFR!\u00E6\u008B\u009B\u00A8c~\b\u00D5\u009A \u0098H\u00A2^ 0\u00B2z\u0096\u00D2\u00FA\tDm\x00$\rY4\x1D\u00E3\r\u00D3D\u00A4\u00C0\u00C7\u00BF7\n*]\u00BF\u008A\u0093\u0081\x16Q\u0085\u00BF\u00E8\u00AD~\u00AB\u009C\u008B\u00EE\x1FWW':\u00D7*\u00FD\u00C8\u00C8]\u00FAI\u00F4g6\u0088\u00CC\u008Fs8\u00A0\u00EE\u0093\u00ECD\u00CA\x0Ba\u00DA\u00C4\u00FCe\u00A8\x0B\u00F8\u008F\u00AA\u00C1\u0093\x15F\x02\u00EB\r\u00F8A\x05\x7FF\u00FD\u009B\f\u0082\u00A4\u00A1\u0088\u00A6\n\u00D97\u00AD\u00DB\u00BF\x01\u0090FT\u00CD\u00D6\u00C7\x18Uo\x04Y\u00B9Y\u00D1UK\x14\x1D\u00F5\u00C8\u00F7R51\u00E8\u00B6\x0BD\u0081\x061\u00D5n_k\u00F9\u00D0\u00E6\u00FF?\u00D3\u00BA\u00B1\u00C4\x11\u009B+\r\x00\x00\x00\x00IEND\u00AEB`\u0082";


    // Creates and displays the script interface
	this.buildUI = function (thisObj)
	{
		// dockable panel or palette
		var pal = (thisObj instanceof Panel) ? thisObj : new Window("palette", this.scriptTitle, undefined, {resizeable:false});

		// resource specifications
		var res =
		"group { orientation:'column', alignment:['left','top'], alignChildren:['right','top'], spacing:5, \
			gr0: Group { alignment:['fill','fill'], \
				header: Image { } \
			}, \
			gr1: Group { \
				aboutBtn: Button { text:'" + this.aboutBtnName + "', preferredSize:[25,20] } \
			}, \
			gr2: Group { alignment:['fill','fill'], alignChildren:['right','top'], \
				runBtn: Button { text:'" + utils.loc(this.runBtnName) + "', alignment:['fill','fill'] } \
			}, \
			gr3: Group { alignment:['fill','fill'], alignChildren:['left','top'], \
				hideAndShyCb: Checkbox { text:'" + utils.loc(this.hideAndShyCbName) + "' } \
			} \
		}";
		pal.gr = pal.add(res);

		pal.gr.gr0.header.image = ScriptUI.newImage(this.headerImgData);

		// event callbacks
		pal.gr.gr1.aboutBtn.onClick = function ()
		{
			utils.createAboutDlg(particularLights.scriptAbout, particularLights.scriptUsage);
		};

		pal.gr.gr2.runBtn.onClick = function ()
		{
			particularLights.create(pal.gr.gr3.hideAndShyCb.value);
		};

		// show user interface
		if (pal instanceof Window)
		{
			pal.center();
			pal.show();
		}
		else
		{
			pal.layout.layout(true);
		}
	};

    // main function
    this.create = function (hideAndShyB)
    {
    	var comp = app.project.activeItem;
		if (!(comp instanceof CompItem) || comp.selectedLayers.length < 1)
		{
			utils.throwErr(this.selAVLayerErr);
			return;
		}

		var selLayers = comp.selectedLayers;

		app.beginUndoGroup(this.scriptName);

		for (var i = 0; i < selLayers.length; i++)
		{
			var lightLayer = comp.layers.addLight("Point Light", [comp.width/2, comp.height/2]);
			lightLayer.lightType = LightType.POINT;

			lightLayer.moveBefore(selLayers[i]);
			lightLayer.name = "Emitter " + (i+1);

			lightLayer.position.expression =
				"res = value;\r" +
				"try\r" +
				"{\r" +
				"   L = thisComp.layer(thisLayer,1);\r" +
				"   try\r" +
				"   {\r" +
				"      res = L.toWorld(L.anchorPoint);\r" +
				"   }\r" +
				"   catch(e)\r" +
				"   {\r" +
				"      try\r" +
				"      {\r" +
				"         res = L.toWorld([0,0,0]);\r" +
				"      }\r" +
				"      catch(e)\r" +
				"      {\r" +
				"      }\r" +
				"   }\r" +
				"}\r" +
				"catch(e)\r" +
				"{\r" +
				"}\r" +
				"res;";

			lightLayer.selected = false;

			if (hideAndShyB)
			{
				selLayers[i].enabled = false;
				selLayers[i].shy = true;
			}
		}

		app.endUndoGroup();
    };

	// Run the script
	this.run = function (thisObj)
	{
		if (parseFloat(app.version) < parseFloat(this.scriptMinSupportVersion))
		{
			utils.throwErr(this.requirementErr);
		}
		else
		{
			this.buildUI(thisObj);
		}
	};
}

function ParticularLightsUtils()
{
	this.loc = function (str)
	{
		var lang = parseFloat(app.version) < 9 ? $.locale : app.isoLanguage;
		return lang.toLowerCase().match("fr") ? str.fr : str.en;
	};

	this.throwErr = function (err)
	{
		var title = $.fileName.substring($.fileName.lastIndexOf("/")+1, $.fileName.lastIndexOf("."));
		alert(this.loc(err), title, true);
	};

	this.createAboutDlg = function (aboutStr, usageStr)
	{
		eval(unescape('%09%09%76%61%72%20%64%6C%67%20%3D%20%6E%65%77%20%57%69%6E%64%6F%77%28%22%64%69%61%6C%6F%67%22%2C%20%22%41%62%6F%75%74%22%29%3B%0A%09%20%20%20%20%20%20%09%20%20%20%20%20%20%20%09%0A%09%20%20%20%20%76%61%72%20%72%65%73%20%3D%0A%09%09%22%67%72%6F%75%70%20%7B%20%6F%72%69%65%6E%74%61%74%69%6F%6E%3A%27%63%6F%6C%75%6D%6E%27%2C%20%61%6C%69%67%6E%6D%65%6E%74%3A%5B%27%66%69%6C%6C%27%2C%27%66%69%6C%6C%27%5D%2C%20%61%6C%69%67%6E%43%68%69%6C%64%72%65%6E%3A%5B%27%66%69%6C%6C%27%2C%27%66%69%6C%6C%27%5D%2C%20%5C%0A%09%09%09%70%6E%6C%3A%20%50%61%6E%65%6C%20%7B%20%74%79%70%65%3A%27%74%61%62%62%65%64%70%61%6E%65%6C%27%2C%20%5C%0A%09%09%09%09%61%62%6F%75%74%54%61%62%3A%20%50%61%6E%65%6C%20%7B%20%74%79%70%65%3A%27%74%61%62%27%2C%20%74%65%78%74%3A%27%44%65%73%63%72%69%70%74%69%6F%6E%27%2C%20%5C%0A%09%09%09%09%09%61%62%6F%75%74%45%74%3A%20%45%64%69%74%54%65%78%74%20%7B%20%74%65%78%74%3A%27%22%20%2B%20%74%68%69%73%2E%6C%6F%63%28%61%62%6F%75%74%53%74%72%29%20%2B%20%22%27%2C%20%70%72%65%66%65%72%72%65%64%53%69%7A%65%3A%5B%33%36%30%2C%32%30%30%5D%2C%20%70%72%6F%70%65%72%74%69%65%73%3A%7B%6D%75%6C%74%69%6C%69%6E%65%3A%74%72%75%65%7D%20%7D%20%5C%0A%09%09%09%09%7D%2C%20%5C%0A%09%09%09%09%75%73%61%67%65%54%61%62%3A%20%50%61%6E%65%6C%20%7B%20%74%79%70%65%3A%27%74%61%62%27%2C%20%74%65%78%74%3A%27%55%73%61%67%65%27%2C%20%5C%0A%09%09%09%09%09%75%73%61%67%65%45%74%3A%20%45%64%69%74%54%65%78%74%20%7B%20%74%65%78%74%3A%27%22%20%2B%20%74%68%69%73%2E%6C%6F%63%28%75%73%61%67%65%53%74%72%29%20%2B%20%22%27%2C%20%70%72%65%66%65%72%72%65%64%53%69%7A%65%3A%5B%33%36%30%2C%32%30%30%5D%2C%20%70%72%6F%70%65%72%74%69%65%73%3A%7B%6D%75%6C%74%69%6C%69%6E%65%3A%74%72%75%65%7D%20%7D%20%5C%0A%09%09%09%09%7D%20%5C%0A%09%09%09%7D%2C%20%5C%0A%09%09%09%62%74%6E%73%3A%20%47%72%6F%75%70%20%7B%20%6F%72%69%65%6E%74%61%74%69%6F%6E%3A%27%72%6F%77%27%2C%20%61%6C%69%67%6E%6D%65%6E%74%3A%5B%27%66%69%6C%6C%27%2C%27%62%6F%74%74%6F%6D%27%5D%2C%20%5C%0A%09%09%09%09%6F%6B%42%74%6E%3A%20%42%75%74%74%6F%6E%20%7B%20%74%65%78%74%3A%27%4F%6B%27%2C%20%61%6C%69%67%6E%6D%65%6E%74%3A%5B%27%72%69%67%68%74%27%2C%27%63%65%6E%74%65%72%27%5D%20%7D%20%5C%0A%09%09%09%7D%20%5C%0A%09%09%7D%22%3B%20%0A%09%09%64%6C%67%2E%67%72%20%3D%20%64%6C%67%2E%61%64%64%28%72%65%73%29%3B%0A%09%09%0A%09%09%64%6C%67%2E%67%72%2E%70%6E%6C%2E%61%62%6F%75%74%54%61%62%2E%61%62%6F%75%74%45%74%2E%6F%6E%43%68%61%6E%67%65%20%3D%20%64%6C%67%2E%67%72%2E%70%6E%6C%2E%61%62%6F%75%74%54%61%62%2E%61%62%6F%75%74%45%74%2E%6F%6E%43%68%61%6E%67%69%6E%67%20%3D%20%66%75%6E%63%74%69%6F%6E%20%28%29%0A%09%09%7B%0A%09%09%09%74%68%69%73%2E%74%65%78%74%20%3D%20%75%74%69%6C%73%2E%6C%6F%63%28%61%62%6F%75%74%53%74%72%29%2E%72%65%70%6C%61%63%65%28%2F%5C%5C%72%2F%67%2C%20%27%5C%72%27%29%3B%0A%09%09%7D%3B%0A%09%09%0A%09%09%64%6C%67%2E%67%72%2E%70%6E%6C%2E%75%73%61%67%65%54%61%62%2E%75%73%61%67%65%45%74%2E%6F%6E%43%68%61%6E%67%65%20%3D%20%64%6C%67%2E%67%72%2E%70%6E%6C%2E%75%73%61%67%65%54%61%62%2E%75%73%61%67%65%45%74%2E%6F%6E%43%68%61%6E%67%69%6E%67%20%3D%20%66%75%6E%63%74%69%6F%6E%20%28%29%0A%09%09%7B%0A%09%09%09%74%68%69%73%2E%74%65%78%74%20%3D%20%75%74%69%6C%73%2E%6C%6F%63%28%75%73%61%67%65%53%74%72%29%2E%72%65%70%6C%61%63%65%28%2F%5C%5C%72%2F%67%2C%20%27%5C%72%27%29%2E%72%65%70%6C%61%63%65%28%2F%5C%5C%27%2F%67%2C%20%22%27%22%29%3B%0A%09%09%7D%3B%0A%09%20%20%20%20%20%20%20%20%20%20%20%20%20%20%20%20%20%0A%09%09%64%6C%67%2E%67%72%2E%62%74%6E%73%2E%6F%6B%42%74%6E%2E%6F%6E%43%6C%69%63%6B%20%3D%20%66%75%6E%63%74%69%6F%6E%20%28%29%20%0A%09%09%7B%0A%09%09%09%64%6C%67%2E%63%6C%6F%73%65%28%29%3B%20%0A%09%09%7D%3B%0A%09%20%20%20%20%20%20%20%0A%09%09%64%6C%67%2E%63%65%6E%74%65%72%28%29%3B%0A%09%09%64%6C%67%2E%73%68%6F%77%28%29%3B'));
	};
}

// Create an instance of the main class and run it
new ParticularLights().run(this);



